HeadlessInAppWebViewWebElement class

Constructors

HeadlessInAppWebViewWebElement({required String id, required BinaryMessenger messenger, required InAppWebViewWebElement? webView})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webView ↔ InAppWebViewWebElement?
getter/setter pair

Methods

dispose() → void
disposeAndGetFlutterWebView() → InAppWebViewWebElement?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onWebViewCreated() → void
setSize(Size size) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited